@@ -1291,7 +1291,7 @@ camel_smime_find_recipients_certs (CERTCertificate *cert,
 
 	/* Cannot short-circuit when frd->certs_missing is 0, because there can be better certificates */
 	if (!frd->recipients_table ||
-	    !(cert->keyUsage & certificateUsageEmailRecipient) ||
+	    !(cert->keyUsage & (KU_KEY_ENCIPHERMENT | KU_DATA_ENCIPHERMENT)) ||
 	    CERT_CheckCertValidTimes (cert, frd->now, PR_FALSE) != secCertTimeValid) {
 		return SECFailure;
 	}
@@ -1444,7 +1444,7 @@ smime_context_encrypt_sync (CamelCipherContext *context,
 
 			/* Default to the provided certificate, if valid */
 			if (cert) {
-				if ((cert->keyUsage & certificateUsageEmailRecipient) != 0 &&
+				if ((cert->keyUsage & (KU_KEY_ENCIPHERMENT | KU_DATA_ENCIPHERMENT)) != 0 &&
 				    CERT_CheckCertValidTimes (cert, frd.now, PR_FALSE) == secCertTimeValid) {
 					recipient_certs[i] = cert;
 					frd.certs_missing--;
